# PrettyIndexer

Are you a beginner programmer or a high school student struggling to write down the index values of a string while slicing it or do you want a visual output of the index values without writing it down, **PrettyIndexer** is your solution. You can do the following with this package.

1. Get a visual display of string along with index values in a tabular form.
2. Get html code of the table displayed

<hr />

## Installation

Run the following to install:

```python
pip install PrettyIndexer
```
<hr />

## Usage

Open in terminal and type the following command

```python
python3 -m stringindexer
```

## Here is a output of the program:

**Terminal output:** 

<img height="300" width="700" src="https://i.imgur.com/cGY5zyK.png?1"/>

**Html Output:**

<img height="200" width="100%" src="https://i.imgur.com/r8oTpbD.png"/>



